🔸Chandrayaan-II (DFSAR) — PolSARtools 0.11 documentation

Skip to main content
`Ctrl`+`K`

# 🔸Chandrayaan-II (DFSAR)

## Full-pol (`import_chyaan2_fp`)

The import_chyaan2_fp function extracts matrix elements (S2/C4/T4/C3/T3/C2/T2 ) from the given Chandrayaan-II folder and saves them into respective directories (S2, C3 or T3).

polsartools.import_chyaan2_fp(in_dir, mat='T3', azlks=None, rglks=None, fmt='tif', cog=False, ovr=[2, 4, 8, 16], comp=False, out_dir=None, recip=False)

  Extracts specified matrix elements (S2, T3, or C3) from Chandrayaan-II DFSAR Full-Pol data and saves them into respective directories.

  ### Example:

      >>> import_chyaan2_fp("path_to_folder", mat='T3', azlks=50, rglks=2)
      This will extract the T3 matrix elements from the Chandrayaan-II DFSAR Full-Pol data
      in the specified folder and save them in the 'T3' directory.

  ### Parameters:

  in_dirstr

    The path to the folder containing the Chandrayaan-II DFSAR Full-Pol data files.

  matstr, optional (default=’T3’)

    Type of matrix to extract. Valid options: ‘S2’, ‘C4, ‘C3’, ‘T4’, ‘T3’, ‘C2HX’, ‘C2VX’, ‘C2HV’,’T2HV’

  azlksint, optional (default=None)

    The number of azimuth looks for multi-looking. If not specified, the value is derived from the ground range and output line spacing.

  rglksint, optional (default=None)

    The number of range looks for multi-looking. If not specified, the value is set to 1.

  fmt{‘tif’, ‘bin’}, optional (default=’tif’)

    Output format: - ‘tif’: GeoTIFF - ‘bin’: Raw binary format

  cogbool, optional (default=False)

    If True, outputs will be saved as Cloud Optimized GeoTIFFs with internal tiling and overviews.

  ovrlist of int, optional (default=[2, 4, 8, 16])

    Overview levels for COG generation. Ignored if cog=False.

  compbool, optional (default=False)

    If True, applies LZW compression to GeoTIFF outputs.

  out_dirstr or None, optional (default=None)

    Directory to save output files. If None, a folder named after the matrix type will be created in the same location as the input file.

  recipbool, optional (default=False)

    If True, scattering matrix reciprocal symmetry is applied, i.e, S_HV = S_VH.

## Compact-pol (`import_chyaan2_cp`)

The import_chyaan2_cp function extracts matrix elements (Sxy, or C2) from the given Chandrayaan-II compact-pol folder and saves them into respective directories.

polsartools.import_chyaan2_cp(in_dir, mat='C2', azlks=None, rglks=None, fmt='tif', cog=False, ovr=[2, 4, 8, 16], comp=False, out_dir=None)

  Extracts specified matrix elements (Sxy, C2) from Chandrayaan-II DFSAR Compact-Pol data and saves them into respective directories.

  ### Example:

      >>> import_chyaan2_cp("path_to_folder", mat='C2', azlks=50, rglks=2)
      This will extract the C2 matrix elements from the Chandrayaan-II DFSAR Compact-Pol data
      in the specified folder and save them in the 'C2' directory.

  ### Parameters:

  in_dirstr

    The path to the folder containing the Chandrayaan-II DFSAR Compact-Pol data files.

  matstr, optional (default=’C2’)

    Type of matrix to extract. Valid options: ‘Sxy’, ‘C2’

  azlksint, optional (default=None)

    The number of azimuth looks for multi-looking. If not specified, the value is derived from the ground range and output line spacing.

  rglksint, optional (default=None)

    The number of range looks for multi-looking. If not specified, the value is set to 1.

  fmt{‘tif’, ‘bin’}, optional (default=’tif’)

    Output format: - ‘tif’: GeoTIFF - ‘bin’: Raw binary format

  cogbool, optional (default=False)

    If True, outputs will be saved as Cloud Optimized GeoTIFFs with internal tiling and overviews.

  ovrlist of int, optional (default=[2, 4, 8, 16])

    Overview levels for COG generation. Ignored if cog=False.

  compbool, optional (default=False)

    If True, applies LZW compression to GeoTIFF outputs.

  out_dirstr or None, optional (default=None)

    Directory to save output files. If None, a folder named after the matrix type will be created in the same location as the input file.